{% extends "admin/base.html" %}
{% load i18n %}

{% block breadcrumbs %}
  <div class="breadcrumbs">
    <a href="{% url 'admin:index' %}">{% translate 'Home' %}</a>
    &rsaquo; {{ title }}
  </div>
{% endblock %}

{% block content %}
<div id="content-main" class="lucus-content">
  <p>{% translate "Something's wrong with your database installation. Make sure the appropriate database tables have been created, and make sure the database is readable by the appropriate user." %}</p>
</div>
{% endblock %}
