{% load i18n %}
<details class="lucus-filter" data-filter-title="{{ title }}">
  <summary class="lucus-filter__summary">
    <span class="lucus-filter__summary-label">{{ title }}</span>
  </summary>
  <ul class="lucus-filter__list">
  {% for choice in choices %}
    <li{% if choice.selected %} class="selected"{% endif %}>
    <a href="{{ choice.query_string|iriencode }}">{{ choice.display }}</a></li>
  {% endfor %}
  </ul>
</details>
