{% extends "admin/base.html" %}
{% load i18n admin_urls static %}

{% block extrahead %}
  {{ block.super }}
  {{ media }}
{% endblock %}

{% block bodyclass %}{{ block.super }} app-{{ opts.app_label }} model-{{ opts.model_name }} delete-confirmation{% endblock %}

{% block breadcrumbs %}
  {% if not is_popup %}
    <div class="breadcrumbs">
      <a href="{% url 'admin:index' %}">{% translate 'Home' %}</a>
      &rsaquo; <a href="{% url opts|admin_urlname:'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a>
      &rsaquo; <a href="{% url opts|admin_urlname:'change' object.pk|admin_urlquote %}">{{ object|truncatewords:"18" }}</a>
      &rsaquo; {% translate 'Delete' %}
    </div>
  {% endif %}
{% endblock %}

{% block content %}
<div id="content-main" class="lucus-content">
  {% if perms_lacking %}
    <p class="errornote">
      {% block delete_forbidden %}
        {% blocktranslate with escaped_object=object %}Deleting the {{ object_name }} '{{ escaped_object }}' would result in deleting related objects, but your account doesn't have permission to delete the following types of objects:{% endblocktranslate %}
      {% endblock %}
    </p>
    {{ perms_lacking|unordered_list }}
  {% elif protected %}
    <p class="errornote">
      {% block delete_protected %}
        {% blocktranslate with escaped_object=object %}Deleting the {{ object_name }} '{{ escaped_object }}' would require deleting the following protected related objects:{% endblocktranslate %}
      {% endblock %}
    </p>
    {{ protected|unordered_list }}
  {% else %}
    <p>
      {% block delete_confirm %}
        {% blocktranslate with escaped_object=object %}Are you sure you want to delete the {{ object_name }} "{{ escaped_object }}"? All of the following related items will be deleted:{% endblocktranslate %}
      {% endblock %}
    </p>
    {% include "admin/includes/object_delete_summary.html" %}
    <h2>{% translate "Objects" %}</h2>
    {{ deleted_objects|unordered_list }}

    <form method="post">{% csrf_token %}
      <div>
        <input type="hidden" name="post" value="yes">
        {% if is_popup %}<input type="hidden" name="{{ is_popup_var }}" value="1">{% endif %}
        {% if to_field %}<input type="hidden" name="{{ to_field_var }}" value="{{ to_field }}">{% endif %}
        <input type="submit" value="{% translate 'Yes, I’m sure' %}">
        <a href="{% url opts|admin_urlname:'change' object.pk|admin_urlquote %}" class="button cancel-link">{% translate "No, take me back" %}</a>
      </div>
    </form>
  {% endif %}
</div>
{% endblock %}
